#
# spec file for package omniORB
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012-2017 Lars Vogdt
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libomniORB4-3
%define libname_omnithread libomnithread4

Name:           omniORB
Summary:        A robust high performance CORBA ORB for C++ and Python
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries
Version:        4.3.2
Release:        1.2
URL:            https://omniorb.sourceforge.io
Source0:        https://downloads.sourceforge.net/project/omniorb/%{name}/%{name}-%{version}/%{name}-%{version}.tar.bz2
Source1:        omniORB-rpmlintrc
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  zlib-devel

%description
omniORB is a robust high performance CORBA ORB for C++ and Python.

It adheres to version 2.6 of the CORBA specification and is fully
interoperable with other CORBA ORBs.

%package devel
Group:          Development/Libraries/C and C++
Summary:        Development libraries, header files and utilities for omniORB
Requires:       %{libname_omnithread} = %{version}
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}

%description devel
omniORB-devel contains the omniORB development files. These
files are needed to develop applications based on omniORB.

%package -n %{libname}
Group:          System/Libraries
Summary:        omniORB libraries
Conflicts:      libomniORB4 <= 4.3.0

%description -n %{libname}
Shared libraries providing the omniORB CORBA implementation.

%package -n %{libname_omnithread}
Group:          System/Libraries
Summary:        omniORB thread library
Conflicts:      libomniORB4 <= 4.3.0

%description -n %{libname_omnithread}
Thread support library for omniORB.

%prep
%setup -q
find . -iname \*\.py -exec sed -ie '1 s@env python@python3@' '{}' \;

%build
%configure --disable-static \
           --with-omniNames-logdir=%{_var}/log/omninames

%make_build

%install
%make_install
mkdir -p %{buildroot}%{_var}/log/omninames
chmod +x %{buildroot}%{python3_sitelib}/omniidl/main.py
chmod +x %{buildroot}%{_libdir}/lib*.so.*

%post -n %{libname} -p /sbin/ldconfig
%post -n %{libname_omnithread} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig
%postun -n %{libname_omnithread} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/lib*.so.*
%exclude %{_libdir}/libomnithread.so.*

%files -n %{libname_omnithread}
%{_libdir}/libomnithread.so.*

%files
%license COPYING*
%doc CREDITS README* ReleaseNotes* src/examples/ziop/README.txt
%doc doc/*
%dir %{_datadir}/idl
%dir %{_datadir}/idl/%{name}
%dir %{_datadir}/idl/%{name}/COS
%dir %{_var}/log/omninames
%dir %{python3_sitelib}/omniidl
%dir %{python3_sitelib}/omniidl_be
%{_bindir}/*
%{python3_sitearch}/_omniidl*
%{python3_sitelib}/omniidl/*
%{python3_sitelib}/omniidl_be/*
%{_datadir}/idl/%{name}/*.idl
%{_datadir}/idl/%{name}/COS/*.idl

%files devel
%license COPYING*
%doc CREDITS README* ReleaseNotes*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*

%changelog
* Tue Jun 18 2024 ming li <mli@suse.com>
- update to 4.3.2:
  * Fixed two cases of crashes due to invalid GIOP sent by
  buggy or malicious clients.
  * Other minor bug fixes.
* Sun Dec 31 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.3.1:
  This is mainly a bugfix release, with minor new features.
  * Support for building with Python 3.12 and later.
  * Miscellaneous bug fixes. See update.log for details.
* Sat Jul 16 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Split library package to adhere with SLPP.
* Mon Feb 14 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.3.0:
  * A new omniORB-specific HTTP / HTTPS transport, with a number of
    capabilities:
    + Full encapsulation of GIOP messages in HTTP.
    + Support for web proxies, transparent web proxies, reverse proxies.
    + For cases where security is important but an end-to-end HTTPS
    connection cannot be assured, support for in-message encryption.
  * New Connection Info callback to receive information about
    connection establishment and errors.
  * New plain object keys POA policy, extending the capabilities of
    omniINSPOA.
  * Support for vast CORBA messages on 64 bit platforms.
  * Support for PyPy in omniidl and omniORBpy.
  * omniCallDescriptor::current() and omniCallHandle::current() to
    access information about the current call on a server.
  * The sslContext class is now in the omni namespace.
  * The marshalled format of exceptions inside Anys has changed for
    compatibility with other ORBs, meaning that it is incompatible
    with omniORB versions prior to 4.3. See the exceptionIdInAny
    configuration parameter to revert to the previous format.
* Thu Nov 25 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unused libidl BuildRequires, just own the dir in filelist.
* Thu Jun 11 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.2.4:
  * Support for C++17 compilers that do not permit throw specifications.
  * Minor bug fixes.
- update to 4.2.3:
  * New retainAddressOrder and resolveNamesForTransportRules options.
  * Experimental support for Mac / iOS CFNetwork connections.
  * Fixed a lock order violation that could lead to a deadlock if
    multiple connections were being opened and closed simultaneously
    in thread pool mode.
- Clean up spec file
- Split shared library package
* Sat May 20 2017 lars@linux-schulserver.de
- update to 4.2.2:
  + Miscellaneous minor fixes based on Coverity testing.
  + Correctly duplicate POA reference in tie class
  + Update GPL / LGPL headers
  + Rely on OpenSSL to check file existence. Clearer error reporting
  + Suppress lots of warnings
  + Log transition between thread per connection and thread pool
  + Locking errors in bidirectional connections
  + Support changed API in OpenSSL 1.1.0
  + New defaultCharCodeSet and defaultWCharCodeSet configuration
    parameters; always use correct exceptions when codesets are missing
  + Unnecessary lock leading to deadlock. Thanks Michael Teske
  + Avoid compiler warnings about unused parameters. Thanks David Ward
    for the request
* Tue Apr 29 2014 lars@linux-schulserver.de
- update to 4.2.0:
  + New listenBacklog parameter. Thanks Peter Klotz
  + Log more detail about SSL errors
  + Support for Python 3 in omniidl
  + Tolerate broken omniNames data files at startup
  + More efficient, but non-standard, union methods
  + Pass Py_BAD_PARAM info through AMI calls
  + Documentation updates
  + Validate UTF-8 more thoroughly. Thanks Peter Klotz.
* Wed Jun 26 2013 lars@linux-schulserver.de
- update to 4.1.7:
  + Bug fixes and platform updates. See bugfixes-416.xml
  + ZIOP support. See
  /usr/share/doc/packages/omniORB/README.txt
  for details.
- removed upstreamed omniORB-4.1.6-prototypes.patch
* Sat Dec 15 2012 lars@linux-schulserver.de
- update to 4.1.6:
  + Bug fixes. See bugfixes-414.xml and bugfixes-415.xml
  + New clientOpenConnection and serverAcceptConnection interceptors
  + Support for building with the newest versions of Cygwin
  + Incoming SSL connections can time out waiting for SSL_accept
    to complete.
  + Ability to disable longdouble support during compilation.
- define omniNames log directory = /var/log/omninames
- add pkg-config to BuildRequires
- specfile cleanup
- license tag follows SPDX.org license strings now
- added omniORB-4.1.6-prototypes.patch
- package bugfixes*.xml files as doc files
* Sun Nov  8 2009 lars@linux-schulserver.de
- update to 4.1.4
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Tue Mar 25 2008 lars@linux-schulserver.de
- repackaged for openSUSE-Education
- disable static library
* Wed Feb 13 2008 Toni Graffy <toni@links2linux.de>
- update to 4.1.2
* Tue Oct  9 2007 Toni Graffy <toni@links2linux.de>
- update to 4.1.1
* Sat Dec 16 2006 Toni Graffy <toni@links2linux.de>
- initial build 4.1.0
- repacked as tar.bz2
